netapp_ontap.models.dcn_node_statistics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_node_statistics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnNodeStatisticsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnNodeStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cpu: DcnNodeStatisticsCpu GET`

    The cpu field of the dcn_node_statistics.

  `gpu: DcnNodeStatisticsGpu GET`

    The gpu field of the dcn_node_statistics.

  `status: str GET`
    - ok: The sample was collected successfully without any errors.
    - error: An internal uncategorized failure occurred during the sample collection.
    - partial_no_data: The sample collection was incomplete due to missing data.
    - partial_no_uuid: The sample collection was incomplete due to a missing UUID.
    - partial_no_response: The sample collection was incomplete due to no response from one or more nodes.
    - partial_other_error: The sample collection was incomplete due to other unspecified errors.
    - negative_delta: An expected monotonically increasing value has decreased in value.
    - backfilled_data: The sample collection was completed at a later time and backfilled to the previous 15-second timestamp.
    - inconsistent_delta_time: The time between two collections is not the same for all nodes, causing the aggregated value to be over or under-inflated.
    - inconsistent_old_data: One or more nodes do not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_uuid
    - partial_no_response
    - partial_other_error
    - negative_delta
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
  `timestamp: ImpreciseDateTime GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000